@@ -4,7 +4,7 @@ from .file_help import import_data_set, store, store_json
 from .classifier import classify
 from .generator import generate
 from .complexity import Complexity, complexity_name
-from .api import get_problem
+from .api import get_problem, get_problems
 
 def classifyAndStore(min_degree, max_degree):
     problems,relaxations,restrictions = import_data_set(min_degree,max_degree,Problem_set.Unclassified)
@@ -70,4 +70,13 @@ def main(argv):
         sys.exit(1)
 
 if __name__ == "__main__":
-   main(sys.argv[1:])
+#    main(sys.argv[1:])
+
+    white_constraint = {'AAC', 'BBB'}
+    black_constraint = {'BC','AA'}
+
+    white_constraint1 = {'AAC', 'BBB'}
+    black_constraint1 = {'BC','AB'}
+    pr = get_problems([(white_constraint, black_constraint), (white_constraint1, black_constraint1)])
+    print(pr)
+
