@@ -10,7 +10,7 @@ def fetch_problems_by_degrees(white_degree, black_degree):
     problems,_, _ = import_data_set(white_degree, black_degree,Problem_set.Classified)
     return problems
 
-def fetch_problems(white_constraint,black_constraint):
+def fetch_problems(white_constraint, black_constraint):
     white_degrees = [len(x) for x in white_constraint]
     black_degrees = [len(x) for x in black_constraint]
 
@@ -31,11 +31,11 @@ def constraints_to_problem(white_constraint, black_constraint):
     return alpha_to_problem(white_constraint, black_constraint)
 
 def get_problems(constraint_tulpes):
-    white_degree = len(constraint_tulpes[0][0][0])
-    black_degree = len(constraint_tulpes[0][1][0])
+    white_degree = len(list(constraint_tulpes[0][0])[0])
+    black_degree = len(list(constraint_tulpes[0][1])[0])
 
     problems = fetch_problems_by_degrees(white_degree, black_degree)
-    problems = {p: p for p in p}
+    problems = {p: p for p in problems}
 
     return [problems[alpha_to_problem(wc, bc)] for (wc, bc) in constraint_tulpes]
 
@@ -92,7 +92,10 @@ def get_upper_bounds_constant_problems(problems):
 
 # white_constraint = {'AAC', 'BBB'}
 # black_constraint = {'BC','AA'}
-# pr = get_problem(white_constraint, black_constraint)
+
+# white_constraint1 = {'AAC', 'BBB'}
+# black_constraint1 = {'BC','AB'}
+# pr = get_problems([(white_constraint, black_constraint), (white_constraint1, black_constraint1)])
 # print(pr)
 
 # white_constraint = {'AC', 'AB', 'CC', 'BC'}
